# Copyright (c) 2014 Thomas Heller
# Copyright (c) 2015 Andreas Schaefer
#
# Distributed under the Boost Software License, Version 1.0. (See accompanying
# file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

# include exported targets if not already defined
if (NOT TARGET hpx)
  include("${CMAKE_CURRENT_LIST_DIR}/HPXTargets.cmake")
endif()

# include HPX cmake utilities
include("${CMAKE_CURRENT_LIST_DIR}/HPXMacros.cmake")

get_filename_component(_hpx_root_dir "${CMAKE_CURRENT_LIST_DIR}/../../.." ABSOLUTE)

set(HPX_INCLUDE_DIRS "/usr/include;/usr/include/hpx/external;/usr/include;/usr/include")

set(HPX_LIBRARIES "hpx;hpx_init;dl;rt;/usr/lib/libboost_chrono.so;/usr/lib/libboost_date_time.so;/usr/lib/libboost_filesystem.so;/usr/lib/libboost_program_options.so;/usr/lib/libboost_regex.so;/usr/lib/libboost_system.so;/usr/lib/libboost_thread.so;/usr/lib/libboost_atomic.so;/usr/lib/libpthread.so;/usr/lib/libboost_context.so;/usr/lib/libboost_random.so;/usr/lib/libboost_system.so;/usr/lib/libboost_atomic.so;/usr/lib/libtcmalloc_minimal.so;/usr/lib/libhwloc.so")
set(HPX_LIBRARY_DIR "")

set(HPX_MAJOR_VERSION 1)
set(HPX_MINOR_VERSION 0)
set(HPX_PATCH_LEVEL   0)

set(HPX_PREFIX "${_hpx_root_dir}")
set(HPX_DEBUG_POSTFIX "d")
set(HPX_BUILD_TYPE "Release")

set(HPX_GIT_COMMIT "unknown" CACHE STRING "Revision of HPX from Git")

set(HPX_C_COMPILER "/usr/bin/cc" CACHE STRING "C compiler for HPX")
set(HPX_C_COMPILER_ID "GNU" CACHE STRING "C compiler id for HPX")
set(HPX_C_COMPILER_VERSION "5.3.0" CACHE STRING "C compiler version for HPX")

set(HPX_CXX_COMPILER "/usr/bin/c++" CACHE STRING "CXX compiler for HPX")
set(HPX_CXX_COMPILER_ID "GNU" CACHE STRING "CXX compiler id for HPX")
set(HPX_CXX_COMPILER_VERSION "5.3.0" CACHE STRING "CXX compiler version for HPX")

set(HPX_Fortran_COMPILER "" CACHE STRING "Fortran compiler for HPX")
set(HPX_Fortran_COMPILER_ID "" CACHE STRING "Fortran compiler id for HPX")
set(HPX_Fortran_COMPILER_VERSION "" CACHE STRING "Fortran compiler version for HPX")

set(HPX_BOOST_ROOT )
set(HPX_WITH_PSEUDO_DEPENDENCIES ON)
set(HPX_WITH_STATIC_LINKING OFF)
set(HPX_WITH_MALLOC_DEFAULT tcmalloc)
set(HPX_WITH_PARCELPORT_TCP ON)
set(HPX_WITH_PARCELPORT_MPI OFF)
set(HPX_WITH_APEX OFF)

if(NOT HPX_CMAKE_LOGLEVEL)
  set(HPX_CMAKE_LOGLEVEL "WARN")
endif()

if(NOT LIB)
  set(LIB "lib")
endif()

enable_language(C)

hpx_check_compiler_compatibility()
hpx_check_boost_compatibility()
hpx_setup_allocator()

if(NOT DEFINED ${CMAKE_FIND_PACKAGE_NAME}_FOUND)
  set(${CMAKE_FIND_PACKAGE_NAME}_FOUND true)
endif()

# Set variables to enable cuda/nvcc or cuda/clang when using add_hpx_executable()
set(HPX_WITH_CUDA OFF)
set(HPX_WITH_CUDA_CLANG OFF)
set(HPX_CUDA_CLANG_FLAGS )

# Set variables used by nvcc
if(HPX_WITH_CUDA AND NOT HPX_WITH_CUDA_CLANG)
    find_package(CUDA REQUIRED)
    set(CUDA_SEPARABLE_COMPILATION ON)
    set(CUDA_NVCC_FLAGS )
    cuda_include_directories("/usr/include;/usr/include/hpx/external;/usr/include;/usr/include")
endif()
